@@ -3,3 +3,12 @@ from .chrome.exceptions import (ChromeException, ChromePathNotFound,
                                 ChromeUserAbortException)
 from .parser.exceptions import ParserException
 from .writer.exceptions import WriterUnknownFileFormat
+
+__all__ = [
+    'ChromeException',
+    'ChromePathNotFound',
+    'ChromeRuntimeException',
+    'ChromeUserAbortException',
+    'ParserException',
+    'WriterUnknownFileFormat',
+]
